@@ -154,7 +154,7 @@ enum : int {
     SBK_QABSTRACTVIDEOFILTER_IDX                             = 6,
     SBK_QABSTRACTVIDEOSURFACE_IDX                            = 7,
     SBK_QABSTRACTVIDEOSURFACE_ERROR_IDX                      = 8,
-    SBK_QAUDIO_IDX                                           = 9,
+    SBK_QtMultimediaQAUDIO_IDX                               = 9,
     SBK_QAUDIO_ERROR_IDX                                     = 10,
     SBK_QAUDIO_STATE_IDX                                     = 13,
     SBK_QAUDIO_MODE_IDX                                      = 11,
@@ -261,7 +261,7 @@ enum : int {
     SBK_QMEDIAVIDEOPROBECONTROL_IDX                          = 114,
     SBK_QMETADATAREADERCONTROL_IDX                           = 115,
     SBK_QMETADATAWRITERCONTROL_IDX                           = 116,
-    SBK_QMULTIMEDIA_IDX                                      = 117,
+    SBK_QtMultimediaQMULTIMEDIA_IDX                          = 117,
     SBK_QMULTIMEDIA_SUPPORTESTIMATE_IDX                      = 121,
     SBK_QMULTIMEDIA_ENCODINGQUALITY_IDX                      = 120,
     SBK_QMULTIMEDIA_ENCODINGMODE_IDX                         = 119,
